Structs
- Config
- This is the entire config - this is what is passed arround in software and what you should use in anything your build
- Config
Save - This is what is saved in a file, the stuff the user can change and edit to fit their needs
- Network
Config - This is the struct that holds the built in , network params that are set by the core devs and the same for everyone